@@ -21,7 +21,8 @@
 import datetime
 import re
 import uuid
-from sqlalchemy import Table, Column, Integer, String, ForeignKey, DateTime
+from sqlalchemy import (Table, Column, Integer, String, Text, ForeignKey,
+                        DateTime)
 from sqlalchemy.orm import relationship, validates
 
 import stalker
@@ -140,7 +141,7 @@ class SimpleEntity(Base):
 
     description = Column(
         "description",
-        String,
+        Text,
         doc="""Description of this object."""
     )
 
@@ -230,8 +231,8 @@ class SimpleEntity(Base):
         post_update=True
     )
 
-    html_style = Column(String, nullable=True, default='')
-    html_class = Column(String, nullable=True, default='')
+    html_style = Column(String(64), nullable=True, default='')
+    html_class = Column(String(64), nullable=True, default='')
 
     __stalker_version__ = Column("stalker_version", String(256))
 
